pub async fn empty_trash(target_prefix: &Path) -> Result<(), UnlinkError>Expand description
Remove files in trash folder that are not currently in use.
pub async fn empty_trash(target_prefix: &Path) -> Result<(), UnlinkError>Remove files in trash folder that are not currently in use.